@@ -3,5 +3,6 @@ var MonteCarloMover_8h =
     [ "MonteCarloMover", "classIMP_1_1core_1_1MonteCarloMover.html", "classIMP_1_1core_1_1MonteCarloMover" ],
     [ "MonteCarloMoverResult", "structIMP_1_1core_1_1MonteCarloMoverResult.html", "structIMP_1_1core_1_1MonteCarloMoverResult" ],
     [ "MonteCarloMoverResults", "MonteCarloMover_8h.html#a7b94b0b09f05406b0ad9348d15437688", null ],
-    [ "MonteCarloMovers", "MonteCarloMover_8h.html#aa055109d0eca853d519c41985667d44e", null ]
+    [ "MonteCarloMovers", "MonteCarloMover_8h.html#aa055109d0eca853d519c41985667d44e", null ],
+    [ "MonteCarloMoversTemp", "MonteCarloMover_8h.html#a98e70d62b4bdb631fa99cb763d982083", null ]
 ];
\ No newline at end of file
