@@ -3,5 +3,6 @@ var Typed_8h =
     [ "Typed", "classIMP_1_1core_1_1Typed.html", "classIMP_1_1core_1_1Typed" ],
     [ "IMP_PARTICLE_TYPE_INDEX", "Typed_8h.html#a732d4d87831e0b38e37081bcfe348b6d", null ],
     [ "ParticleType", "Typed_8h.html#a9127fedb0bdc9f5706b46e561f06e505", null ],
-    [ "ParticleTypes", "Typed_8h.html#a549b73a9cc72e2db164ccd0850230290", null ]
+    [ "ParticleTypes", "Typed_8h.html#a549b73a9cc72e2db164ccd0850230290", null ],
+    [ "Typeds", "Typed_8h.html#a11d64d842959f01fb4081b63e030acff", null ]
 ];
\ No newline at end of file
