@@ -4,7 +4,9 @@ var Writer_8h =
     [ "Writer", "classIMP_1_1display_1_1Writer.html", "classIMP_1_1display_1_1Writer" ],
     [ "WriterAdaptor", "classIMP_1_1display_1_1WriterAdaptor.html", "classIMP_1_1display_1_1WriterAdaptor" ],
     [ "TextWriters", "Writer_8h.html#aa183025d9797b55d6520ff90f9c9d520", null ],
+    [ "TextWritersTemp", "Writer_8h.html#a3f843d54b9ce8a6f785efce11b3cd64c", null ],
     [ "WriterAdaptors", "Writer_8h.html#a144d1cadcee25ee07afe7e531251f09b", null ],
     [ "Writers", "Writer_8h.html#a5918cc718637e57ab0b464a9bd11d509", null ],
+    [ "WritersTemp", "Writer_8h.html#a6820324d2c955570dd63b82da98c86f2", null ],
     [ "create_writer", "Writer_8h.html#a55414a3681ffd79c126fabdbf13abb2d", null ]
 ];
\ No newline at end of file
