@@ -5,6 +5,5 @@ var classIMP_1_1algebra_1_1FixedXYZ =
     [ "get_x", "classIMP_1_1algebra_1_1FixedXYZ.html#a04665eeef1d3f44033eafb152b38d0aa", null ],
     [ "get_y", "classIMP_1_1algebra_1_1FixedXYZ.html#a63635555d006a9c89b9e1a40b205516a", null ],
     [ "get_z", "classIMP_1_1algebra_1_1FixedXYZ.html#a2c49470ff97ed29536081e6e9fe90d5a", null ],
-    [ "show", "classIMP_1_1algebra_1_1FixedXYZ.html#afe11ded0e32c3e08b3da17e24cbd294e", null ],
-    [ "get_rotation_from_fixed_xyz", "classIMP_1_1algebra_1_1FixedXYZ.html#a3553256ff422012e5b18d02a13412da0", null ]
+    [ "show", "classIMP_1_1algebra_1_1FixedXYZ.html#afe11ded0e32c3e08b3da17e24cbd294e", null ]
 ];
\ No newline at end of file
