@@ -8,5 +8,7 @@ var classIMP_1_1algebra_1_1NearestNeighborD =
     [ "get_nearest_neighbor", "classIMP_1_1algebra_1_1NearestNeighborD.html#aa9d12e5ed704b01a530c058ec5a466ab", null ],
     [ "get_nearest_neighbors", "classIMP_1_1algebra_1_1NearestNeighborD.html#a19ac6ba3425b78f1fa10ab6fe5ca6410", null ],
     [ "get_nearest_neighbors", "classIMP_1_1algebra_1_1NearestNeighborD.html#a7beece69ce6579d62acad7e1bb8fed83", null ],
+    [ "get_type_name", "classIMP_1_1algebra_1_1NearestNeighborD.html#ab5e014a688aafe3a1f1b373577a63bef", null ],
+    [ "get_version_info", "classIMP_1_1algebra_1_1NearestNeighborD.html#a6f9d80efbac0ebfdb8477a602cb4e4a4", null ],
     [ "set_query_log", "classIMP_1_1algebra_1_1NearestNeighborD.html#abf675a682240798340ae1613af8971a3", null ]
 ];
\ No newline at end of file
