@@ -2,8 +2,8 @@ var classIMP_1_1atom_1_1CHARMMResidueTopology =
 [
     [ "CHARMMResidueTopology", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#acd586e0463d6dddd9399956945c4e5cc", null ],
     [ "CHARMMResidueTopology", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#adf36f0b3ed6504c273e75a78dd024e70", null ],
-    [ "do_show", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#ad060ca30a7945ec417845de6a620f6ad", null ],
     [ "get_patched", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#a840a01a59dc15094ef1b24c4e82bf2af", null ],
-    [ "set_patched", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#a53ecd73b013b44d66ba7982237561a14", null ],
-    [ "CHARMMResidueTopologiesTemp", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#a04190e1f931a18df560569ed770ff960", null ]
+    [ "get_type_name", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#a242b7ce9a4226210267bafacf5406c52", null ],
+    [ "get_version_info", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#acbcb03693ffb55359a94dfe2b83b71ab", null ],
+    [ "set_patched", "classIMP_1_1atom_1_1CHARMMResidueTopology.html#a53ecd73b013b44d66ba7982237561a14", null ]
 ];
\ No newline at end of file
