@@ -1,13 +1,17 @@
 var classIMP_1_1base_1_1Object =
 [
     [ "Object", "classIMP_1_1base_1_1Object.html#a984ca522763b56684601c96fe091fe6d", null ],
+    [ "Object", "classIMP_1_1base_1_1Object.html#a9c2049dab55c81cd66d7af81fc901708", null ],
     [ "clear_caches", "classIMP_1_1base_1_1Object.html#a5ec0fa3df8aa5878b916b6f9fd88c27f", null ],
+    [ "do_destroy", "classIMP_1_1base_1_1Object.html#ae6e594095b0951cb98c3ae4e00c9ab4b", null ],
+    [ "get_check_level", "classIMP_1_1base_1_1Object.html#a06c0e03c2227d204d45705c0bda00cc3", null ],
+    [ "get_log_level", "classIMP_1_1base_1_1Object.html#a613214d356ea9024baf8014fce4da96c", null ],
     [ "get_name", "classIMP_1_1base_1_1Object.html#ade62a34cdade4913ee2a53844151e776", null ],
-    [ "get_version_info", "classIMP_1_1base_1_1Object.html#a1b9ce6d6a809ac67e54a4b29aa97ddb7", null ],
+    [ "get_type_name", "classIMP_1_1base_1_1Object.html#a849db5d2865621367714ec83ba731b42", null ],
+    [ "get_version_info", "classIMP_1_1base_1_1Object.html#aa9d33f201b91a0d2275f74dc110beed7", null ],
     [ "set_check_level", "classIMP_1_1base_1_1Object.html#ae839ec84964c2fd7341af5ca5ec74c0a", null ],
     [ "set_log_level", "classIMP_1_1base_1_1Object.html#a69f4b4fd1c675daa7f46bec9d6cf9613", null ],
     [ "set_name", "classIMP_1_1base_1_1Object.html#afd6a17163b856db1693fb41db4625d88", null ],
     [ "set_was_used", "classIMP_1_1base_1_1Object.html#a345269851934e22c259d6392d1b1117b", null ],
-    [ "show", "classIMP_1_1base_1_1Object.html#a8571ef897a69bc1a9f35349bbea29a30", null ],
-    [ "ObjectsTemp", "classIMP_1_1base_1_1Object.html#aa1c0e1f19d9127fa52072f39405969f1", null ]
+    [ "show", "classIMP_1_1base_1_1Object.html#a8571ef897a69bc1a9f35349bbea29a30", null ]
 ];
\ No newline at end of file
