@@ -4,7 +4,8 @@ var classIMP_1_1container_1_1DistributeTripletsScoreState =
     [ "add_predicate", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#a73b67981a22dc16bb6dc985ff85e26ae", null ],
     [ "do_after_evaluate", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#a451f4cfc5fd99b0b3ca458865315e399", null ],
     [ "do_before_evaluate", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#a962a332daab88ddc0068a134bb853fe8", null ],
-    [ "do_get_inputs", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#aac23bf159b46476cf7dcb73fc47c211a", null ],
-    [ "do_get_outputs", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#a253a842380909b0db24dfdab08bc32eb", null ],
-    [ "do_show", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#aeea4191f2039afd22342b10b1f31247e", null ]
+    [ "do_get_inputs", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#ad5532d0be4afbd8ba83221db080748cc", null ],
+    [ "do_get_outputs", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#a5715cf125d50a19dbce8e8de799bb3c1", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#ae0b7de3bf2e843ff98a7fb40ce52f87d", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1DistributeTripletsScoreState.html#a112337807fe113cb7370eaf633604d1c", null ]
 ];
\ No newline at end of file
