@@ -4,5 +4,7 @@ var classIMP_1_1container_1_1DynamicListPairContainer =
     [ "add_particle_pair", "classIMP_1_1container_1_1DynamicListPairContainer.html#a38f49583bc6f46211206a362a870dd72", null ],
     [ "add_particle_pairs", "classIMP_1_1container_1_1DynamicListPairContainer.html#ae0e989ac4f176d690e877700736addef", null ],
     [ "clear_particle_pairs", "classIMP_1_1container_1_1DynamicListPairContainer.html#a14c035bad040437ea96bf089de6c2e88", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1DynamicListPairContainer.html#aadcf65e215ab3d92a1a84974216b1bef", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1DynamicListPairContainer.html#a43061cfc796791c0b862360b5466f18e", null ],
     [ "set_particle_pairs", "classIMP_1_1container_1_1DynamicListPairContainer.html#aaf843556cb1b92417656ab9b497a921e", null ]
 ];
\ No newline at end of file
