@@ -4,5 +4,7 @@ var classIMP_1_1container_1_1DynamicListTripletContainer =
     [ "add_particle_triplet", "classIMP_1_1container_1_1DynamicListTripletContainer.html#a6a090de3bd7e95351eb8ef8e6150a95c", null ],
     [ "add_particle_triplets", "classIMP_1_1container_1_1DynamicListTripletContainer.html#a9df71e18dfba457be90d9e7f2f0c5be7", null ],
     [ "clear_particle_triplets", "classIMP_1_1container_1_1DynamicListTripletContainer.html#a57272d7bb46c32b8c7d2618f3b2d1d23", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1DynamicListTripletContainer.html#a7fa0b93d0ff1c9c1b98179ad73380ecb", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1DynamicListTripletContainer.html#a85f9755055d66f9ba5bc894b0fe5d0cd", null ],
     [ "set_particle_triplets", "classIMP_1_1container_1_1DynamicListTripletContainer.html#abbb9bd992d6906b0349e3ca21123646d", null ]
 ];
\ No newline at end of file
