@@ -1,7 +1,9 @@
 var classIMP_1_1container_1_1ListQuadContainer =
 [
-    [ "ListQuadContainer", "classIMP_1_1container_1_1ListQuadContainer.html#a8925b4fbec23ae0f4258b4e0a0394b26", null ],
+    [ "ListQuadContainer", "classIMP_1_1container_1_1ListQuadContainer.html#ab8da5f0a8d744ac7f975bd83883ddb09", null ],
     [ "ListQuadContainer", "classIMP_1_1container_1_1ListQuadContainer.html#a46daa7ae26cadab901e72abb9b4a93a0", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1ListQuadContainer.html#af102e0c6ec7cbce01de9fa49bb8d2919", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1ListQuadContainer.html#a68794db4885bc4a816a0f640204d9bd6", null ],
     [ "set_particle_quads", "classIMP_1_1container_1_1ListQuadContainer.html#af4a1937ee2cce0f90b5418bb0c22b7f6", null ],
     [ "set_particle_quads", "classIMP_1_1container_1_1ListQuadContainer.html#ab68611ce81005c4c0a12f99436cfdfd2", null ]
 ];
\ No newline at end of file
