@@ -1,7 +1,9 @@
 var classIMP_1_1container_1_1ListTripletContainer =
 [
-    [ "ListTripletContainer", "classIMP_1_1container_1_1ListTripletContainer.html#a4b46f28ad25de2ff073d2c6d7b3b4166", null ],
+    [ "ListTripletContainer", "classIMP_1_1container_1_1ListTripletContainer.html#af580b3f013a829d0588b3e3bbd7d81bb", null ],
     [ "ListTripletContainer", "classIMP_1_1container_1_1ListTripletContainer.html#accec53b0c3251278c38bae2866aff9c3", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1ListTripletContainer.html#a7d8f1a41284f529975cf9c93403cb6ed", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1ListTripletContainer.html#a5543bae22eb1347648fe6089be5cd1dd", null ],
     [ "set_particle_triplets", "classIMP_1_1container_1_1ListTripletContainer.html#a467c5d7807a2e8147856ad7a907f350f", null ],
     [ "set_particle_triplets", "classIMP_1_1container_1_1ListTripletContainer.html#a2b676b9553c95340356c98802d98a0e8", null ]
 ];
\ No newline at end of file
