@@ -1,7 +1,9 @@
 var classIMP_1_1container_1_1MinimumSingletonRestraint =
 [
     [ "MinimumSingletonRestraint", "classIMP_1_1container_1_1MinimumSingletonRestraint.html#afc6016d7b8306d113c7aac80f9fad916", null ],
-    [ "do_get_inputs", "classIMP_1_1container_1_1MinimumSingletonRestraint.html#a39361525293be0a0a2af12bd029748fb", null ],
+    [ "do_get_inputs", "classIMP_1_1container_1_1MinimumSingletonRestraint.html#a645f093b22f292eae986d3cd52f0071e", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1MinimumSingletonRestraint.html#af8dc89f5320f74de5e87a94fb05ea06b", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1MinimumSingletonRestraint.html#afcd1fcf5fb2b50f7c3b44aae8f4d1548", null ],
     [ "set_n", "classIMP_1_1container_1_1MinimumSingletonRestraint.html#a37b992f313f321d9d3cdc20b0e289b9c", null ],
     [ "unprotected_evaluate", "classIMP_1_1container_1_1MinimumSingletonRestraint.html#a7ae2ef49b43adf416ea8f39052d5c303", null ]
 ];
\ No newline at end of file
