@@ -1,7 +1,9 @@
 var classIMP_1_1container_1_1MinimumTripletRestraint =
 [
     [ "MinimumTripletRestraint", "classIMP_1_1container_1_1MinimumTripletRestraint.html#ab3fe22bd709e5092001fb5475fb20162", null ],
-    [ "do_get_inputs", "classIMP_1_1container_1_1MinimumTripletRestraint.html#a7c63fbc28098f3253937a0c2ea72d144", null ],
+    [ "do_get_inputs", "classIMP_1_1container_1_1MinimumTripletRestraint.html#af3bd86c9dde4819137f65c5f4ee31072", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1MinimumTripletRestraint.html#ab40c2e6ec034ee7c4c0f7a408fcaa3fd", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1MinimumTripletRestraint.html#ab911fcf767c2416ba1c82e8e2522e2ec", null ],
     [ "set_n", "classIMP_1_1container_1_1MinimumTripletRestraint.html#ac3a3dc629d61b6dd30298ba22a7e1b1a", null ],
     [ "unprotected_evaluate", "classIMP_1_1container_1_1MinimumTripletRestraint.html#aeb502a0766bb46e7cee24217aaf2960a", null ]
 ];
\ No newline at end of file
