@@ -3,7 +3,10 @@ var classIMP_1_1container_1_1PairContainerStatistics =
     [ "PairContainerStatistics", "classIMP_1_1container_1_1PairContainerStatistics.html#a1b0661cecd4ff309fb9847ab6a4d1ae5", null ],
     [ "do_after_evaluate", "classIMP_1_1container_1_1PairContainerStatistics.html#a925b3bba141ee6816450216f6d1ffc37", null ],
     [ "do_before_evaluate", "classIMP_1_1container_1_1PairContainerStatistics.html#a2fd3bdb8be875159819fae39f3469674", null ],
-    [ "do_show", "classIMP_1_1container_1_1PairContainerStatistics.html#a8c05c3c8a08c0fde30207e0061f8c341", null ],
+    [ "do_get_inputs", "classIMP_1_1container_1_1PairContainerStatistics.html#afe300ac87f278ca8baa1062233b5b8e0", null ],
+    [ "do_get_outputs", "classIMP_1_1container_1_1PairContainerStatistics.html#a27e61b3a8418dd8640b0cb682aec4127", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1PairContainerStatistics.html#ab743421b4ab646f50af05daa089e8629", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1PairContainerStatistics.html#a6f95589d0b77cc04b365bd883538fd97", null ],
     [ "set_track_unique", "classIMP_1_1container_1_1PairContainerStatistics.html#abdeca4feb824463c5a3c88ee7f5ae07c", null ],
     [ "show_statistics", "classIMP_1_1container_1_1PairContainerStatistics.html#a8beee49c15c0cd83d0c88436ffb5f604", null ]
 ];
\ No newline at end of file
