@@ -2,8 +2,10 @@ var classIMP_1_1container_1_1PredicatePairsRestraint =
 [
     [ "PredicatePairsRestraint", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a71d534ebe79712a2697c44d45f103190", null ],
     [ "do_add_score_and_derivatives", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a1b4220f06cf860b3345a4aeb69f08f8a", null ],
-    [ "do_get_inputs", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a3d68b65dcdef399d51e0a4a0d47eb082", null ],
+    [ "do_get_inputs", "classIMP_1_1container_1_1PredicatePairsRestraint.html#ac5f33298fd80da5ea29b322e92db2f43", null ],
     [ "get_indexes", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a9035c457ba89bddc90f402c0f78adfaf", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1PredicatePairsRestraint.html#aebcb74cabe771b842f64cf88872b0750", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a2bf793e76bdaaca9d6f6408eee78bdd6", null ],
     [ "set_is_complete", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a9eabdec2fa689e6e176016b18cd6c3d4", null ],
     [ "set_score", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a266285050ea266635ea46d3ae198975e", null ],
     [ "set_unknown_score", "classIMP_1_1container_1_1PredicatePairsRestraint.html#a46914f9f300d0566e483af0358f1dcde", null ]
