@@ -2,8 +2,10 @@ var classIMP_1_1container_1_1PredicateSingletonsRestraint =
 [
     [ "PredicateSingletonsRestraint", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a84f8347debda23cf2d99b2e2b0695ddb", null ],
     [ "do_add_score_and_derivatives", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a9488c2fbe9f45c079c5142bd5c2a34d9", null ],
-    [ "do_get_inputs", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a4084024d693f5d334f56f694e544e35c", null ],
+    [ "do_get_inputs", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a0f7be78f51b602a52f1caf45e6b89c1e", null ],
     [ "get_indexes", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#afe7b9e126e74db54f3f9023a00b52009", null ],
+    [ "get_type_name", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#abb1729f7895bc22a0ccfa474b3321bea", null ],
+    [ "get_version_info", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a3dd565e113ceed586ec67d7305be87c5", null ],
     [ "set_is_complete", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a631d667261925726f724f7173eafa215", null ],
     [ "set_score", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a57b74d41e99ef3c769187354dc38867c", null ],
     [ "set_unknown_score", "classIMP_1_1container_1_1PredicateSingletonsRestraint.html#a194581da9eb2ff86a377d55fdf93cadd", null ]
