@@ -6,6 +6,8 @@ var classIMP_1_1core_1_1Harmonic =
     [ "get_k", "classIMP_1_1core_1_1Harmonic.html#a6ec2da8036ce3ab740d97c03895751cf", null ],
     [ "get_k_from_standard_deviation", "classIMP_1_1core_1_1Harmonic.html#a34646455a8a2e301f2895d99a525b914", null ],
     [ "get_mean", "classIMP_1_1core_1_1Harmonic.html#ada961123970f4bf81700a699292a23b1", null ],
+    [ "get_type_name", "classIMP_1_1core_1_1Harmonic.html#a5439799727f0e9e589bf9b1c49a2814c", null ],
+    [ "get_version_info", "classIMP_1_1core_1_1Harmonic.html#a84104af4203a863c3eceb30d358f4957", null ],
     [ "set_k", "classIMP_1_1core_1_1Harmonic.html#a5021be58b31fc4ce3350707df42b438f", null ],
     [ "set_mean", "classIMP_1_1core_1_1Harmonic.html#a32c7052e555e7fb18e0e5c0bbd58f1f9", null ]
 ];
\ No newline at end of file
