@@ -3,11 +3,13 @@ var classIMP_1_1core_1_1MSConnectivityRestraint =
     [ "MSConnectivityRestraint", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a10d36b52d84c2cc74fd727dcf884c17e", null ],
     [ "add_composite", "classIMP_1_1core_1_1MSConnectivityRestraint.html#aa8028889a273ed4b062624055b0550e6", null ],
     [ "add_composite", "classIMP_1_1core_1_1MSConnectivityRestraint.html#ad38af7c9ec4f04921a48456975e2a085", null ],
-    [ "add_type", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a8af8ed2fcecc6f1d927d0c9f3240b330", null ],
-    [ "do_create_current_decomposition", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a8dde56f38e6d8f3a0b50aa263fcab8be", null ],
-    [ "do_get_inputs", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a3c461f2d0e65922e7ed2634d6bafa0dd", null ],
-    [ "get_connected_pairs", "classIMP_1_1core_1_1MSConnectivityRestraint.html#aeff5f05f8033e9a136043e4dc5ed1047", null ],
+    [ "add_type", "classIMP_1_1core_1_1MSConnectivityRestraint.html#ac38d45755d9c5407cc3c3a1f27389269", null ],
+    [ "do_create_current_decomposition", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a196cb8de65098fc5fbd1cb87c2be324a", null ],
+    [ "do_get_inputs", "classIMP_1_1core_1_1MSConnectivityRestraint.html#ad16b78bd75a2fd4687f228831764336a", null ],
+    [ "get_connected_pairs", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a45a26125179d6abbfda2d18fc66fe8d1", null ],
     [ "get_pair_score", "classIMP_1_1core_1_1MSConnectivityRestraint.html#adbb8bd7d4b45c8f7ce115788afd16b13", null ],
+    [ "get_type_name", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a7fca9482e81dc8672bb0e61fd4be4249", null ],
+    [ "get_version_info", "classIMP_1_1core_1_1MSConnectivityRestraint.html#a944ca7e8aaf110fa3a28438c2b6e3c5f", null ],
     [ "unprotected_evaluate", "classIMP_1_1core_1_1MSConnectivityRestraint.html#acbbb248c2357046bf7a5f97daf755368", null ],
     [ "MSConnectivityScore", "classIMP_1_1core_1_1MSConnectivityRestraint.html#af0f42c332f3ba46d4944ada50cd016c6", null ]
 ];
\ No newline at end of file
