@@ -3,5 +3,7 @@ var classIMP_1_1core_1_1TruncatedHarmonic =
     [ "TruncatedHarmonic", "classIMP_1_1core_1_1TruncatedHarmonic.html#aeb558426c32dbf24f5bbc1314ccc721d", null ],
     [ "TruncatedHarmonic", "classIMP_1_1core_1_1TruncatedHarmonic.html#ae0a2f4ac0d3d0a41c84ba72e348a3f3e", null ],
     [ "evaluate", "classIMP_1_1core_1_1TruncatedHarmonic.html#ac4ceedf03af30553ab7f832473237beb", null ],
-    [ "evaluate_with_derivative", "classIMP_1_1core_1_1TruncatedHarmonic.html#a8a98ab9262765c456e4c93922bde6558", null ]
+    [ "evaluate_with_derivative", "classIMP_1_1core_1_1TruncatedHarmonic.html#a8a98ab9262765c456e4c93922bde6558", null ],
+    [ "get_type_name", "classIMP_1_1core_1_1TruncatedHarmonic.html#a995fd8f8b9ddfcf8f7ec29c55aa46ba0", null ],
+    [ "get_version_info", "classIMP_1_1core_1_1TruncatedHarmonic.html#a0c5bcf00bcdd404fb4ad227d3dd03a31", null ]
 ];
\ No newline at end of file
