@@ -4,7 +4,9 @@ var classIMP_1_1display_1_1CylinderGeometry =
     [ "CylinderGeometry", "classIMP_1_1display_1_1CylinderGeometry.html#ab08ceebc8704d641be302119db1ebb73", null ],
     [ "CylinderGeometry", "classIMP_1_1display_1_1CylinderGeometry.html#a31190a41e1a7354c221761274eaf5f34", null ],
     [ "CylinderGeometry", "classIMP_1_1display_1_1CylinderGeometry.html#af38ad28d6d178422d8db293d14b7d646", null ],
-    [ "do_show", "classIMP_1_1display_1_1CylinderGeometry.html#ab64d5d08d439f305f50702706f47c213", null ],
+    [ "get_components", "classIMP_1_1display_1_1CylinderGeometry.html#ac15f741549c7093c57c73b199ffabd1e", null ],
     [ "get_geometry", "classIMP_1_1display_1_1CylinderGeometry.html#a68933bd92183b7af45927c57be378355", null ],
+    [ "get_type_name", "classIMP_1_1display_1_1CylinderGeometry.html#af84b096b851bbc904b7e360f383d89b7", null ],
+    [ "get_version_info", "classIMP_1_1display_1_1CylinderGeometry.html#aa464d8c9552cc8fedc5dbc33749c1bee", null ],
     [ "set_geometry", "classIMP_1_1display_1_1CylinderGeometry.html#abf3c1eee4096e672e2f5ed468c766e0f", null ]
 ];
\ No newline at end of file
