@@ -4,7 +4,9 @@ var classIMP_1_1display_1_1EllipsoidGeometry =
     [ "EllipsoidGeometry", "classIMP_1_1display_1_1EllipsoidGeometry.html#a8b23de125510a349978b1b789743ea33", null ],
     [ "EllipsoidGeometry", "classIMP_1_1display_1_1EllipsoidGeometry.html#ae80469cfe57e39a43311da048a65b785", null ],
     [ "EllipsoidGeometry", "classIMP_1_1display_1_1EllipsoidGeometry.html#a880be80c539c27f6e16c0a38a9fa9c9c", null ],
-    [ "do_show", "classIMP_1_1display_1_1EllipsoidGeometry.html#abbaba49e2587c3b1b0cc7489da8189d1", null ],
+    [ "get_components", "classIMP_1_1display_1_1EllipsoidGeometry.html#ae50c8e2f2fbddd42c2b0116b7eed1ad8", null ],
     [ "get_geometry", "classIMP_1_1display_1_1EllipsoidGeometry.html#a1286b6c9386a8f436b0170b13a1b638c", null ],
+    [ "get_type_name", "classIMP_1_1display_1_1EllipsoidGeometry.html#a404469579b39b3cc44ce3c854648a5d6", null ],
+    [ "get_version_info", "classIMP_1_1display_1_1EllipsoidGeometry.html#a0a7e9daf346fa0f226224d14b9e933e7", null ],
     [ "set_geometry", "classIMP_1_1display_1_1EllipsoidGeometry.html#a06dbe9b339d4fdb16b7f76b095ff4cf7", null ]
 ];
\ No newline at end of file
