@@ -4,7 +4,9 @@ var classIMP_1_1display_1_1PolygonGeometry =
     [ "PolygonGeometry", "classIMP_1_1display_1_1PolygonGeometry.html#acd5cc1ee58451042ac360b2302916b6a", null ],
     [ "PolygonGeometry", "classIMP_1_1display_1_1PolygonGeometry.html#ae6bb2e5df83f72f59111ccc6c9bccbf3", null ],
     [ "PolygonGeometry", "classIMP_1_1display_1_1PolygonGeometry.html#ac357ffc56fb03894e549a5e5d9a20b7e", null ],
-    [ "do_show", "classIMP_1_1display_1_1PolygonGeometry.html#a0160fd549dbab1e6fbb150e25efda605", null ],
+    [ "get_components", "classIMP_1_1display_1_1PolygonGeometry.html#a1c53bb302db602aa5c908b3bd67cc1d8", null ],
     [ "get_geometry", "classIMP_1_1display_1_1PolygonGeometry.html#a4d935284e4e42ec0dd7b10dfd1b4f6f3", null ],
+    [ "get_type_name", "classIMP_1_1display_1_1PolygonGeometry.html#a6f6bcb7205c9792b282ac20af99bf4b3", null ],
+    [ "get_version_info", "classIMP_1_1display_1_1PolygonGeometry.html#ae895ee80887a6e3e4f7f2a40e10fdf15", null ],
     [ "set_geometry", "classIMP_1_1display_1_1PolygonGeometry.html#af46b9f164c984dea04dfff4633770606", null ]
 ];
\ No newline at end of file
