@@ -1,6 +1,8 @@
 var classIMP_1_1em2d_1_1JPGImageReaderWriter =
 [
     [ "JPGImageReaderWriter", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a7b526d778654e71d5f8fb9a7d2d504bd", null ],
+    [ "get_type_name", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a393420c811e388d4b7ce27dc8c52acf8", null ],
+    [ "get_version_info", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#aef07c925bde0f482ec77c9854ef56e88", null ],
     [ "read", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#ada85593d93e916c209685881c7a4fcd5", null ],
     [ "read_from_floats", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#abe4ea8ee65e316e0642cfd0dadd2aaaa", null ],
     [ "read_from_ints", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a3dd656c0f71e7189264c6d57aad86aab", null ],
