@@ -1,8 +1,8 @@
 var classIMP_1_1em_1_1HighDensityEmbedding =
 [
     [ "HighDensityEmbedding", "classIMP_1_1em_1_1HighDensityEmbedding.html#a15ad76f739395c5555e9ade9bbed66ed", null ],
-    [ "do_show", "classIMP_1_1em_1_1HighDensityEmbedding.html#a3cc43a323ad3a90e2e128b919bafdf53", null ],
     [ "get_number_of_items", "classIMP_1_1em_1_1HighDensityEmbedding.html#acb48544e34a6d37ef349dd3ab6c179e9", null ],
     [ "get_point", "classIMP_1_1em_1_1HighDensityEmbedding.html#acc908e69940b82a7dde4c789a07baacd", null ],
-    [ "get_points", "classIMP_1_1em_1_1HighDensityEmbedding.html#a97afb201d38dfb3b285e5a9db0387bdd", null ]
+    [ "get_type_name", "classIMP_1_1em_1_1HighDensityEmbedding.html#ab0097b8c4356ea1eee62a072a44bd304", null ],
+    [ "get_version_info", "classIMP_1_1em_1_1HighDensityEmbedding.html#a99a3386131fef85a6cc8788d54d5c3b8", null ]
 ];
\ No newline at end of file
