@@ -2,6 +2,8 @@ var classIMP_1_1em_1_1SpiderMapReaderWriter =
 [
     [ "SpiderMapReaderWriter", "classIMP_1_1em_1_1SpiderMapReaderWriter.html#a4ab73c84a83bb313d8ea54b56f315656", null ],
     [ "SpiderMapReaderWriter", "classIMP_1_1em_1_1SpiderMapReaderWriter.html#a7e20644389966deeb8ffa2a66d7555ce", null ],
+    [ "get_type_name", "classIMP_1_1em_1_1SpiderMapReaderWriter.html#af12657c112f2132131deb9dfa7db6243", null ],
+    [ "get_version_info", "classIMP_1_1em_1_1SpiderMapReaderWriter.html#ac6c32f0ad2dd1e5d95323f03ecc52764", null ],
     [ "read", "classIMP_1_1em_1_1SpiderMapReaderWriter.html#aa73bc0929bf35db8b546d109f7e8d0c1", null ],
     [ "write", "classIMP_1_1em_1_1SpiderMapReaderWriter.html#a6a4605a4c76247437791dc46e4ab2d41", null ],
     [ "filename_", "classIMP_1_1em_1_1SpiderMapReaderWriter.html#a95e64bd187a253db0ac9fa7c3dbaa241", null ],
