@@ -7,6 +7,8 @@ var classIMP_1_1isd_1_1FNormal =
     [ "evaluate_derivative_FM", "classIMP_1_1isd_1_1FNormal.html#aab7e0152585dcef7a18ff1e1b11fea7c", null ],
     [ "evaluate_derivative_JA", "classIMP_1_1isd_1_1FNormal.html#a41bdcb717106e023a7abb8556b3f3061", null ],
     [ "evaluate_derivative_sigma", "classIMP_1_1isd_1_1FNormal.html#a6f2836ae8389c83a194d8a574d0e94ab", null ],
+    [ "get_type_name", "classIMP_1_1isd_1_1FNormal.html#a64d316b49a2964de9e9c80e4bd2c2652", null ],
+    [ "get_version_info", "classIMP_1_1isd_1_1FNormal.html#a45f0e62a68b93dc11a7977dbdd089f9a", null ],
     [ "set_FA", "classIMP_1_1isd_1_1FNormal.html#a293a1285135fbd732a06e959aea1904d", null ],
     [ "set_FM", "classIMP_1_1isd_1_1FNormal.html#ae0d6daa4bbb61435781944662213f83b", null ],
     [ "set_JA", "classIMP_1_1isd_1_1FNormal.html#a41b5c0d56af50a48ae8767a1f4154349", null ],
