@@ -1,8 +1,8 @@
 var classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding =
 [
     [ "ConfigurationSetXYZEmbedding", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#a59f36e0f094ff45193a47939d8d93cd1", null ],
-    [ "do_show", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#a879b59e1499c9e0113ce1c86a5adb621", null ],
     [ "get_number_of_items", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#afe49b0466c1468ccc5fd46fd4e0466a4", null ],
     [ "get_point", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#a73541be0c29324ff18d03ad6cac51b08", null ],
-    [ "get_points", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#aaf325736f39c8d04f178b879327829cf", null ]
+    [ "get_type_name", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#a0597c1057209f57d21234089ec735584", null ],
+    [ "get_version_info", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#a9fc0079127a998ef7194664bd07c0a8d", null ]
 ];
\ No newline at end of file
