@@ -1,8 +1,8 @@
 var classIMP_1_1statistics_1_1VectorDEmbedding =
 [
     [ "VectorDEmbedding", "classIMP_1_1statistics_1_1VectorDEmbedding.html#adc7396de005b3afac5181cad5807dc15", null ],
-    [ "do_show", "classIMP_1_1statistics_1_1VectorDEmbedding.html#a5ee4d0d25a6263983a9922fa2b53fa0f", null ],
     [ "get_number_of_items", "classIMP_1_1statistics_1_1VectorDEmbedding.html#aaeccf62928ac5472c1f55ac36c33be2d", null ],
     [ "get_point", "classIMP_1_1statistics_1_1VectorDEmbedding.html#ab99085602658220b18669293fca21367", null ],
-    [ "get_points", "classIMP_1_1statistics_1_1VectorDEmbedding.html#ad79c0c4d8ff88a249fd1405422155b2e", null ]
+    [ "get_type_name", "classIMP_1_1statistics_1_1VectorDEmbedding.html#a70d1db0ac846bddc0922aa29a18b7770", null ],
+    [ "get_version_info", "classIMP_1_1statistics_1_1VectorDEmbedding.html#ac26c8b992e86a4c6c72f81e45c6514c7", null ]
 ];
\ No newline at end of file
